==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/LekPostac.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class LekPostac extends GenericDPSObject {
    /**
     * LEK_POSTAC.KOD_BAZYL
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long kodBazyl;

    /**
     * LEK_POSTAC.LEK_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long lekId;

    /**
     * LEK_POSTAC.DOP_OBROT_POLSKA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean dopObrotPolska;

    /**
     * LEK_POSTAC.OPAKOWANIE_ILOSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal opakowanieIlosc;

    /**
     * LEK_POSTAC.OPAKOWANIE_OPIS_BAZYL
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String opakowanieOpisBazyl;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return LEK_POSTAC.KOD_BAZYL
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKodBazyl() {
        return kodBazyl;
    }

    /**
     * LEK_POSTAC.KOD_BAZYL
     *
     * @param kodBazyl
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKodBazyl(Long kodBazyl) {
        this.kodBazyl = kodBazyl;
    }

    /**
     * @return LEK_POSTAC.LEK_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getLekId() {
        return lekId;
    }

    /**
     * LEK_POSTAC.LEK_ID
     *
     * @param lekId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setLekId(Long lekId) {
        this.lekId = lekId;
    }

    /**
     * @return LEK_POSTAC.DOP_OBROT_POLSKA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getDopObrotPolska() {
        return dopObrotPolska;
    }

    /**
     * LEK_POSTAC.DOP_OBROT_POLSKA
     *
     * @param dopObrotPolska
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDopObrotPolska(Boolean dopObrotPolska) {
        this.dopObrotPolska = dopObrotPolska;
    }

    /**
     * @return LEK_POSTAC.OPAKOWANIE_ILOSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getOpakowanieIlosc() {
        return opakowanieIlosc;
    }

    /**
     * LEK_POSTAC.OPAKOWANIE_ILOSC
     *
     * @param opakowanieIlosc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOpakowanieIlosc(BigDecimal opakowanieIlosc) {
        this.opakowanieIlosc = opakowanieIlosc;
    }

    /**
     * @return LEK_POSTAC.OPAKOWANIE_OPIS_BAZYL
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getOpakowanieOpisBazyl() {
        return opakowanieOpisBazyl;
    }

    /**
     * LEK_POSTAC.OPAKOWANIE_OPIS_BAZYL
     *
     * @param opakowanieOpisBazyl
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOpakowanieOpisBazyl(String opakowanieOpisBazyl) {
        this.opakowanieOpisBazyl = opakowanieOpisBazyl == null ? null : opakowanieOpisBazyl.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        LekPostac other = (LekPostac) that;
        return (this.getKodBazyl() == null ? other.getKodBazyl() == null : this.getKodBazyl().equals(other.getKodBazyl()))
            && (this.getLekId() == null ? other.getLekId() == null : this.getLekId().equals(other.getLekId()))
            && (this.getDopObrotPolska() == null ? other.getDopObrotPolska() == null : this.getDopObrotPolska().equals(other.getDopObrotPolska()))
            && (this.getOpakowanieIlosc() == null ? other.getOpakowanieIlosc() == null : this.getOpakowanieIlosc().equals(other.getOpakowanieIlosc()))
            && (this.getOpakowanieOpisBazyl() == null ? other.getOpakowanieOpisBazyl() == null : this.getOpakowanieOpisBazyl().equals(other.getOpakowanieOpisBazyl()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getKodBazyl() == null) ? 0 : getKodBazyl().hashCode());
        result = prime * result + ((getLekId() == null) ? 0 : getLekId().hashCode());
        result = prime * result + ((getDopObrotPolska() == null) ? 0 : getDopObrotPolska().hashCode());
        result = prime * result + ((getOpakowanieIlosc() == null) ? 0 : getOpakowanieIlosc().hashCode());
        result = prime * result + ((getOpakowanieOpisBazyl() == null) ? 0 : getOpakowanieOpisBazyl().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", kodBazyl=").append(kodBazyl);
        sb.append(", lekId=").append(lekId);
        sb.append(", dopObrotPolska=").append(dopObrotPolska);
        sb.append(", opakowanieIlosc=").append(opakowanieIlosc);
        sb.append(", opakowanieOpisBazyl=").append(opakowanieOpisBazyl);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/LekPostac.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class LekPostac extends GenericDPSObject {
    /**
     * LEK_POSTAC.KOD_BAZYL
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long kodBazyl;

    /**
     * LEK_POSTAC.LEK_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long lekId;

    /**
     * LEK_POSTAC.DOP_OBROT_POLSKA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean dopObrotPolska;

    /**
     * LEK_POSTAC.OPAKOWANIE_ILOSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal opakowanieIlosc;

    /**
     * LEK_POSTAC.OPAKOWANIE_OPIS_BAZYL
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String opakowanieOpisBazyl;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return LEK_POSTAC.KOD_BAZYL
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKodBazyl() {
        return kodBazyl;
    }

    /**
     * LEK_POSTAC.KOD_BAZYL
     *
     * @param kodBazyl
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKodBazyl(Long kodBazyl) {
        this.kodBazyl = kodBazyl;
    }

    /**
     * @return LEK_POSTAC.LEK_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getLekId() {
        return lekId;
    }

    /**
     * LEK_POSTAC.LEK_ID
     *
     * @param lekId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setLekId(Long lekId) {
        this.lekId = lekId;
    }

    /**
     * @return LEK_POSTAC.DOP_OBROT_POLSKA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getDopObrotPolska() {
        return dopObrotPolska;
    }

    /**
     * LEK_POSTAC.DOP_OBROT_POLSKA
     *
     * @param dopObrotPolska
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDopObrotPolska(Boolean dopObrotPolska) {
        this.dopObrotPolska = dopObrotPolska;
    }

    /**
     * @return LEK_POSTAC.OPAKOWANIE_ILOSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getOpakowanieIlosc() {
        return opakowanieIlosc;
    }

    /**
     * LEK_POSTAC.OPAKOWANIE_ILOSC
     *
     * @param opakowanieIlosc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOpakowanieIlosc(BigDecimal opakowanieIlosc) {
        this.opakowanieIlosc = opakowanieIlosc;
    }

    /**
     * @return LEK_POSTAC.OPAKOWANIE_OPIS_BAZYL
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getOpakowanieOpisBazyl() {
        return opakowanieOpisBazyl;
    }

    /**
     * LEK_POSTAC.OPAKOWANIE_OPIS_BAZYL
     *
     * @param opakowanieOpisBazyl
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOpakowanieOpisBazyl(String opakowanieOpisBazyl) {
        this.opakowanieOpisBazyl = opakowanieOpisBazyl == null ? null : opakowanieOpisBazyl.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        LekPostac other = (LekPostac) that;
        return (this.getKodBazyl() == null ? other.getKodBazyl() == null : this.getKodBazyl().equals(other.getKodBazyl()))
            && (this.getLekId() == null ? other.getLekId() == null : this.getLekId().equals(other.getLekId()))
            && (this.getDopObrotPolska() == null ? other.getDopObrotPolska() == null : this.getDopObrotPolska().equals(other.getDopObrotPolska()))
            && (this.getOpakowanieIlosc() == null ? other.getOpakowanieIlosc() == null : this.getOpakowanieIlosc().equals(other.getOpakowanieIlosc()))
            && (this.getOpakowanieOpisBazyl() == null ? other.getOpakowanieOpisBazyl() == null : this.getOpakowanieOpisBazyl().equals(other.getOpakowanieOpisBazyl()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getKodBazyl() == null) ? 0 : getKodBazyl().hashCode());
        result = prime * result + ((getLekId() == null) ? 0 : getLekId().hashCode());
        result = prime * result + ((getDopObrotPolska() == null) ? 0 : getDopObrotPolska().hashCode());
        result = prime * result + ((getOpakowanieIlosc() == null) ? 0 : getOpakowanieIlosc().hashCode());
        result = prime * result + ((getOpakowanieOpisBazyl() == null) ? 0 : getOpakowanieOpisBazyl().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", kodBazyl=").append(kodBazyl);
        sb.append(", lekId=").append(lekId);
        sb.append(", dopObrotPolska=").append(dopObrotPolska);
        sb.append(", opakowanieIlosc=").append(opakowanieIlosc);
        sb.append(", opakowanieOpisBazyl=").append(opakowanieOpisBazyl);
        sb.append("]");
        return sb.toString();
    }
}
